@@ -33,12 +33,14 @@ def main():
         "-m",
         "--minimum-rating",
         metavar="rating",
+        type=int,
         help="The minimum rating of games to consider",
     )
     parser.add_argument(
         "-M",
         "--maximum-rating",
         metavar="rating",
+        type=int,
         help="The maximum rating of games to consider",
     )
     parser.add_argument(
@@ -127,7 +129,7 @@ def main():
     for game in games:
         if should_display_progress_bar:
             progress_bar.update(1)
-        print(game)
+        print(game, end="\n\n")
 
     stream.close()
 
