@@ -82,6 +82,8 @@ class TimeControl(Enum):
     CORRESPONDENCE = (21600, 2147483647)
 
     def matches(self, other):
+        if "+" not in other:
+            return False
         clock, increment = other.split("+")
         lower_bound, upper_bound = self.value
 
